# kiss-ai-stack - types

Common types for kiss-ai-stack's components.

To install,

```python
pip install kiss-ai-stack-types
```

### License

This library is licensed under the MIT License - see the [LICENSE](./LICENSE) file for details.
